@@ -1,5 +1,5 @@
 # Verilog - Verilog Perl Interface
-# $Id: Net.pm 35112 2007-04-02 13:44:27Z wsnyder $
+# $Id: Net.pm 39061 2007-05-21 14:49:55Z wsnyder $
 # Author: Wilson Snyder <wsnyder@wsnyder.org>
 ######################################################################
 #
@@ -21,7 +21,7 @@ use Verilog::Netlist;
 use Verilog::Netlist::Subclass;
 @ISA = qw(Verilog::Netlist::Net::Struct
 	Verilog::Netlist::Subclass);
-$VERSION = '2.373';
+$VERSION = '2.380';
 use strict;
 
 ######################################################################
@@ -182,8 +182,8 @@ Verilog::Netlist::Net - Net for a Verilog Module
 
 =head1 DESCRIPTION
 
-Verilog::Netlist creates a net for every sc_signal declaration in the
-current module.
+A Verilog::Netlist::Net object is created by Verilog::Netlist::Module for
+every signal and input/output declaration in the current module.
 
 =head1 ACCESSORS
 
@@ -263,6 +263,7 @@ Wilson Snyder <wsnyder@wsnyder.org>
 
 =head1 SEE ALSO
 
+L<Verilog-Perl>,
 L<Verilog::Netlist::Subclass>
 L<Verilog::Netlist>
 
