@@ -1,5 +1,5 @@
 # Verilog - Verilog Perl Interface
-# $Id: Port.pm 35112 2007-04-02 13:44:27Z wsnyder $
+# $Id: Port.pm 39061 2007-05-21 14:49:55Z wsnyder $
 # Author: Wilson Snyder <wsnyder@wsnyder.org>
 ######################################################################
 #
@@ -21,7 +21,7 @@ use Verilog::Netlist;
 use Verilog::Netlist::Subclass;
 @ISA = qw(Verilog::Netlist::Port::Struct
 	Verilog::Netlist::Subclass);
-$VERSION = '2.373';
+$VERSION = '2.380';
 use strict;
 
 structs('new',
@@ -104,8 +104,8 @@ Verilog::Netlist::Port - Port for a Verilog Module
 
 =head1 DESCRIPTION
 
-Verilog::Netlist creates a port for every connection to the outside
-world in the current module.
+A Verilog::Netlist::Port object is created by Verilog::Netlist::Module for
+every port connection in the module.
 
 =head1 ACCESSORS
 
@@ -173,6 +173,7 @@ Wilson Snyder <wsnyder@wsnyder.org>
 
 =head1 SEE ALSO
 
+L<Verilog-Perl>,
 L<Verilog::Netlist::Subclass>
 L<Verilog::Netlist>
 
